@@ -3,6 +3,6 @@ globalVariables(
         "outside",".cluster","centers","glance","k_means","prop_of_total","tot.withinss",
         "total_records","PC","var_explained","cum_var_pct","ou_threshold",
         "iterations","number_of_clusters","within_cluster_sum_of_squares","wss",
-        "predict","predicted_cluster"
+        "predict","predicted_cluster","printer","rand_id"
     )
 )
